@@ -2,10 +2,11 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from .purchase_request import *
+
+from . import stock
 
 
 def register():
     Pool.register(
-        PurchaseRequest,
-        module='stock_supply_forecast', type_='model')
+        stock.Supply,
+        module='stock_supply_forecast', type_='wizard')
